#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
%define		lfsvers		20230818
#-----------------------------------------------------------------------------
Name		:	udev
Version		:	255
Release		:	14.8.0.0%{?dist}
Summary		:	Udev from Systemd

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	GPLv2+
URL		:	https://www.freedesktop.org/wiki/Software/systemd/

Source0		:	systemd-%{version}.tar.gz
			#https://anduin.linuxfromscratch.org/LFS/systemd-man....
Source1		:	systemd-man-pages-%{version}.tar.xz
Source2		:	%{name}-lfs-%{lfsvers}.tar.xz
Source3		:	%{name}-ok_addon.tar.gz
#-----------------------------------------------------------------------------
Buildrequires	:	kmod
Buildrequires	:	util-linux
Buildrequires	:	xz-devel
Buildrequires	:	python3-Jinja2

Requires(pre)	:	kmod,util-linux
#-----------------------------------------------------------------------------
%description
Starting with the 2.5 kernel, all physical and virtual devices in a
system are visible to userspace in a hierarchal fashion through
sysfs. /sbin/hotplug provides a notification to userspace when any
device is added or removed from the system. Using these two features,
a userspace implementation of a dynamic /dev is now possible that can
provide a very flexible device naming policy

%files
%defattr(-,root,root,-)
%doc README README.md
#=============================================================================
%package		-n e%{name}
Summary		:	file to access udev device information

#-----------------------------------------------------------------------------
%description		-n e%{name} 
This package provides binary to access eudev device information

#-----------------------------------------------------------------------------
%files			-n e%{name}
%defattr(-,root,root,-)
%{_bindir}/%{name}adm
%{_bindir}/%{name}-hwdb
%{_sbindir}/%{name}d
%{_sysconfdir}/%{name}/%{name}.conf
%{_sysconfdir}/%{name}/rules.d/*.rules
%{_sysconfdir}/rc.d/init.d/%{name}
%{_sysconfdir}/rc.d/rcS.d/S10%{name}
%dir %{_sysconfdir}/%{name}/hwdb.d
%{_libdir}/%{name}/ata_id
%{_libdir}/%{name}/cdrom_id
%{_libdir}/%{name}/dmi_memory_id
%{_libdir}/%{name}/fido_id
%{_libdir}/%{name}/iocost
%{_libdir}/%{name}/mtd_probe
%{_libdir}/%{name}/scsi_id
%{_libdir}/%{name}/v4l_id
%{_libdir}/%{name}/rules.d/README
%{_libdir}/%{name}/rules.d/*.rules
%{_libdir}/%{name}/hwdb.d/README
%{_libdir}/%{name}/hwdb.d/[1-9]0-*.hwdb
%{_libdir}/%{name}/hwdb.d/82-net-auto-link-local.hwdb
%{_libdir}/%{name}/init-net-rules.sh
%{_libdir}/%{name}/rule_generator.functions
%{_libdir}/%{name}/write_net_rules
%{_defaultdocdir}/%{name}-%{lfsvers}/*
%{_mandir}/man5/%{name}.conf.5.gz
%{_mandir}/man7/%{name}.7.gz
%{_mandir}/man8/%{name}*.8.gz


#-----------------------------------------------------------------------------
%post			-n e%{name}
#to take care of new hardware definition
%{_bindir}/%{name}-hwdb update


#=============================================================================
%package		-n e%{name}-libs
Summary		:	Shared library to access udev device information

#-----------------------------------------------------------------------------
%description		-n e%{name}-libs 
This package provides shared library to access eudev device information

#-----------------------------------------------------------------------------
%files			-n e%{name}-libs
%defattr(-,root,root,-)
%{_libdir}/lib%{name}.so.1*

#=============================================================================
%package		-n e%{name}-devel
Summary		:	Development libraries for eudev

#-----------------------------------------------------------------------------
Requires	:	e%{name}-libs = %{version}-%{release}

#-----------------------------------------------------------------------------
%description		-n e%{name}-devel 
Header and Library files for doing development with the eudev.

#-----------------------------------------------------------------------------
%files			-n e%{name}-devel
%defattr(-,root,root,-)
%{_includedir}/libudev.h 
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_datadir}/pkgconfig/%{name}.pc

#=============================================================================
%prep
%setup -q -n systemd-%{version}
tar xf %{SOURCE1}
tar xf %{SOURCE2}
tar xf %{SOURCE3}

#Remove two unneeded groups, render and sgx,
#from the default udev rules:

sed -i								\
  -e 's/GROUP="render"/GROUP="video"/'				\
  -e 's/GROUP="sgx", //'					\
  rules.d/50-udev-default.rules.in

#Remove one udev rule requiring a full Systemd installation:
sed -i								\
  -e '/systemd-sysctl/s/^/#/'					\
  rules.d/99-systemd.rules.in

#-----------------------------------------------------------------------------
#building application
%build

#Prepare Udev for compilation:
meson setup							\
	--prefix=%{_prefix}					\
	--buildtype=release					\
	-D mode=release						\
	-D dev-kvm-mode=0660					\
	-D link-udev-shared=false				\
	-D logind=false						\
	-D vconsole=false					\
	_bld							\

pushd	_bld	> /dev/null

#Get the list of the shipped udev helpers and
#save it into an environment variable
udev_helpers=$(grep "'name' :" ../src/udev/meson.build | \
               awk '{print $3}' | tr -d ",'" | grep -v 'udevadm')

ninja								\
	udevadm							\
	systemd-hwdb						\
	$(grep -o -E 						\
	  "^build (src/libudev|src/udev|rules.d|hwdb.d)[^:]*"	\
          build.ninja | awk '{ print $2 }')			\
	$(realpath libudev.so --relative-to .)			\
	$udev_helpers udevadm

#Remove one udev rule file requiring a full Systemd installation
rm								\
	rules.d/90-vconsole.rules

popd

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

%{__make}							\
        -f udev-lfs-%{lfsvers}/Makefile.lfs			\
        DESTDIR=%{buildroot}					\
        install

#installing udev part of systemd
pushd	_bld	> /dev/null

#Get the list of the shipped udev helpers and
#save it into an environment variable
udev_helpers=$(grep "'name' :" ../src/udev/meson.build | \
               awk '{print $3}' | tr -d ",'" | grep -v 'udevadm')

install -m755 -d %{buildroot}%{_bindir}
install -m755 							\
	%{name}adm						\
	%{buildroot}%{_bindir}

install -m755 							\
	systemd-hwdb						\
	%{buildroot}%{_bindir}/%{name}-hwdb

install -m755 -d %{buildroot}%{_sbindir}
%{__ln_s}							\
	../bin/%{name}adm					\
	%{buildroot}%{_sbindir}/%{name}d
	
install -m755 -d %{buildroot}%{_libdir}/pkgconfig
install -m644 							\
	./src/libudev/*.pc					\
	%{buildroot}%{_libdir}/pkgconfig/
cp      -a							\
	libudev.so{,*[0-9]}  					\
	%{buildroot}%{_libdir}

install -m755 -d %{buildroot}%{_datadir}/pkgconfig
install -m644 							\
	./src/udev/*.pc						\
	%{buildroot}%{_datadir}/pkgconfig/

install -m755 -d %{buildroot}%{_includedir}
install -m644							\
	../src/libudev/libudev.h				\
	%{buildroot}%{_includedir}/

install -m755 -d %{buildroot}%{_libdir}/%{name}/rules.d/
install -m644							\
	rules.d/* 						\
	../rules.d/{*.rules,README}				\
	%{buildroot}%{_libdir}/%{name}/rules.d/

install -m755 -d %{buildroot}%{_sysconfdir}/%{name}/hwdb.d
install -m755 -d %{buildroot}%{_libdir}/%{name}/hwdb.d

install -m644							\
	hwdb.d/* 						\
	../hwdb.d/{*.hwdb,README}				\
	 %{buildroot}%{_libdir}/%{name}/hwdb.d

install -m755 -d %{buildroot}%{_sysconfdir}/%{name}/
install -m644							\
	../src/%{name}/%{name}.conf				\
	%{buildroot}%{_sysconfdir}/%{name}/

install -vm755							\
	$udev_helpers						\
	%{buildroot}%{_libdir}/%{name}/

popd
	

#installing manual
install -m755 -d %{buildroot}%{_mandir}/{man5,man7,man8}

%{__cp} -a							\
	systemd-man-pages-%{version}/man5/%{name}.conf.5	\
	%{buildroot}%{_mandir}/man5/
%{__cp} -a							\
	systemd-man-pages-%{version}/man7/%{name}.7		\
	%{buildroot}%{_mandir}/man7/
%{__cp} -a							\
	systemd-man-pages-%{version}/man8/%{name}adm.8		\
	%{buildroot}%{_mandir}/man8/
sed 								\
 -e 's|lib.*udevd|sbin/udevd|'					\
 systemd-man-pages-%{version}/man8/systemd-%{name}d.service.8	\
 > %{buildroot}%{_mandir}/man8/%{name}.8

#setup init file 
%{__mkdir_p}							\
	%{buildroot}%{_sysconfdir}/rc.d/init.d			\
	%{buildroot}%{_sysconfdir}/rc.d/rcS.d
%{__cp} -a							\
	%{name}-ok_addon/%{name}.init				\
	%{buildroot}%{_sysconfdir}/rc.d/init.d/%{name}
%{__ln_s}							\
	../init.d/%{name}					\
	%{buildroot}%{_sysconfdir}/rc.d/rcS.d/S10%{name}

	
#-----------------------------------------------------------------------------
%changelog
